<?php
/*
Plugin Name: WooCommerce Order Product Image Column
Plugin URI: https://www.visualmoxie.com
Description: This adds a column to your WooCommerce Order page that displays the product thumbnail image related to the order.
Version: 2.0
Author: Tom McGuire | Visual Moxie (VisualMoxie.com)
Plugin URI: https://www.visualmoxie.com
*/

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
        die;
}

// Load the plugin only in the admin dashboard
if (is_admin()) {
    // Add a new column named "Order Image(s)" to WooCommerce order list
    add_filter('manage_edit-shop_order_columns', 'opt_woo_admin_orders_list_add_column', 10, 1);

    // Display the content for new column in the order list
    add_action('manage_shop_order_posts_custom_column', 'opt_woo_add_product_image_order_column', 10, 2);

    // Add plugin settings page under the Tools menu
    add_action('admin_menu', 'opt_woo_settings_page');

    // Register settings and add nonce verification and error handling
    add_action('admin_init', 'opt_woo_register_settings');
}

function opt_woo_admin_orders_list_add_column($columns)
{
    // Give the order page column a heading
    $columns['custom_column'] = __('Order Image(s)', 'woocommerce');
    return $columns;
}

function opt_woo_add_product_image_order_column($column, $post_id)
{
    if ('custom_column' === $column) {
        $order = wc_get_order($post_id);

        // Get plugin settings
        $size = get_option('opt_thumbnail_size', 70);
        $radius = get_option('opt_border_radius', 10);
        $spacing = get_option('opt_thumbnail_spacing', 4);

        // Loop through order items
        foreach ($order->get_items() as $item) {
            $product = $item->get_product(); // The WC_Product Object
            $image = $product->get_image(array($size, $size));
            $name = $product->get_name(); // Get the product name

            $style = sprintf(
                'width: %spx; height: %spx; border: %spx solid transparent; border-radius: %spx; margin-right: %spx;',
                $size,
                $size,
                $spacing,
                $radius,
                $spacing
            );

            $image = sprintf(
                '<span class="opt_zoomable-image" title="%s" style="%s">%s</span>',
                esc_attr($name),
                esc_attr($style),
                $image
            );

            // Display product thumbnail with zoom effect and tooltip
            echo $image;
        }

        // Include CSS and JavaScript for image zoom effect and tooltip
        echo '<style>
            .opt_zoomable-image {
                display: inline-block;
                position: relative;
                overflow: hidden;
                box-sizing: border-box;
                transition: transform 0.3s ease;
            }

            .opt_zoomable-image:hover {
                transform: scale(1.1);
            }
            .opt_zoomable-image img {
                width: 100%;
                height: 100%;
                display: block;
            }
        </style>';
    }
}

function opt_woo_settings_page()
{
    add_submenu_page(
        'tools.php', // parent menu slug
        'WooCommerce Order Product Image Column', // page title
        'Woo Order Thumbs', // menu title
        'manage_options', // capability
        'order-image-settings', // menu slug
        'opt_woo_render_settings_page' // callback function to render the settings page
    );
}

function opt_woo_render_settings_page()
{
    ?>
<style>	   .wrap {
        	max-width: 800px; /* Adjust the value to your desired maximum width */
        	margin: 0 auto; /* Center the container */
        	padding: 20px; /* Add padding for better readability (optional) */
    		}</style>
    <div class="wrap">
        <h2>WooCommerce Order Page Purchased Image Column</h2>
        <p>Enhance your WooCommerce order management experience with the WooCommerce Product Order Image Column plugin. This feature-rich extension adds a visually appealing "Order Image" column to your WooCommerce Order Pages, displaying product thumbnail images related to each order. Quickly identify products, improve order processing efficiency, and customize display settings with ease. Fine-tune the plugin through the intuitive settings page, adjusting thumbnail size, thumbnail corner radius, and thumbnail spacing. Elevate your WooCommerce order admin interface with this powerful and user-friendly enhancement.</p>
        <form method="post" action="options.php">
            <?php
            settings_fields('order_image_settings');
            do_settings_sections('order_image_settings');
            wp_nonce_field('opt_woo_settings_nonce', 'opt_woo_settings_nonce'); // Add nonce field
            submit_button();
            ?>
            <p>&copy; 2023 Tom McGuire | <a href="http://VisualMoxie.com" target="_blank">VisualMoxie.com</a></p>
        </form>
    </div>
    <?php
}

function opt_woo_register_settings()
{
    register_setting('order_image_settings', 'opt_thumbnail_size', 'intval');
    register_setting('order_image_settings', 'opt_border_radius', 'intval');
    register_setting('order_image_settings', 'opt_thumbnail_spacing', 'intval');

    add_settings_section('order_image_section', 'How to use the plugin', 'opt_woo_order_image_section_callback', 'order_image_settings');

    add_settings_field('opt_thumbnail_size', 'Thumbnail Size (in pixels)', 'opt_woo_thumbnail_size_callback', 'order_image_settings', 'order_image_section');
    add_settings_field('opt_border_radius', 'Thumbnail Corner Radius (in pixels)', 'opt_woo_border_radius_callback', 'order_image_settings', 'order_image_section');
    add_settings_field('opt_thumbnail_spacing', 'Thumbnail Spacing (in pixels)', 'opt_woo_thumbnail_spacing_callback', 'order_image_settings', 'order_image_section');
}

function opt_woo_order_image_section_callback()
{
    echo '<p>
<li><strong>Thumbnail Size</strong> sets the size of the square thumbnail which will grow 10% when you hover over it. Adjust this size as needed so your thumbnail grid is nice and compact for multiple item orders.</li>
<li><strong>Thumbnail Corner Radius</strong> gives the thumbnails a little bit of a rounded corner to them. Not necessary but is a nice touch.</li>
<li><strong>Thumbnail Spacing</strong> This setting is used to accomodate the +10% scaling when you hover over the thumbnail. A setting of 0 in this option will result in your thumbnail appearing behind others when you hover over it for multiple item orders.</li>
</p>';
}

function opt_woo_thumbnail_size_callback()
{
    $option = get_option('opt_thumbnail_size', 70);
    echo '<input type="text" name="opt_thumbnail_size" value="' . esc_attr($option) . '" /> px';
    echo '<p class="description">Set the size in pixels for the square thumbnail images.</p>';
}

function opt_woo_border_radius_callback()
{
    $option = get_option('opt_border_radius', 10);
    echo '<input type="text" name="opt_border_radius" value="' . esc_attr($option) . '" /> px';
    echo '<p class="description">Set the corner radius in pixels for the thumbnail images.</p>';
}

function opt_woo_thumbnail_spacing_callback()
{
    $option = get_option('opt_thumbnail_spacing', 4);
    echo '<input type="text" name="opt_thumbnail_spacing" value="' . esc_attr($option) . '" /> px';
    echo '<p class="description">Set the spacing in pixels between thumbnail images.</p>';
}

// Validate and sanitize options before saving
function opt_woo_validate_options($input)
{
    $output = array();
    // Validate and sanitize 'opt_thumbnail_size'
    if (isset($input['opt_thumbnail_size'])) {
        $output['opt_thumbnail_size'] = intval($input['opt_thumbnail_size']);
    }

    // Validate and sanitize 'opt_border_radius'
    if (isset($input['opt_border_radius'])) {
        $output['opt_border_radius'] = intval($input['opt_border_radius']);
    }

    // Validate and sanitize 'opt_thumbnail_spacing'
    if (isset($input['opt_thumbnail_spacing'])) {
        $output['opt_thumbnail_spacing'] = intval($input['opt_thumbnail_spacing']);
    }

    return $output;
}

// Add nonce verification and error handling
function opt_woo_settings_sanitize_and_save()
{
    if (isset($_POST['opt_woo_settings_nonce']) && wp_verify_nonce($_POST['opt_woo_settings_nonce'], 'opt_woo_settings_nonce')) {
        // Nonce is valid, process the form data

        // Validate and sanitize options before saving
        $sanitized_input = opt_woo_validate_options($_POST);

        // Save the sanitized options to the database
        update_option('opt_thumbnail_size', $sanitized_input['opt_thumbnail_size']);
        update_option('opt_border_radius', $sanitized_input['opt_border_radius']);
        update_option('opt_thumbnail_spacing', $sanitized_input['opt_thumbnail_spacing']);
    }
}

// Hook the save function to the 'admin_init' action
add_action('admin_init', 'opt_woo_settings_sanitize_and_save');
